@@ -17,7 +17,7 @@
 ### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 ### MA 02110-1301, USA
 
-gvisTable <- function(data, options=list(), chartid){
+gvisTable <- function(data, options=list(), chartid, formats = NULL){
 
   my.type <- "Table"
   dataName <- deparse(substitute(data))
@@ -27,7 +27,8 @@ gvisTable <- function(data, options=list(), chartid){
   
   checked.data <- gvisCheckTableData(data)
   
-  output <- gvisChart(type=my.type, checked.data=checked.data, options=my.options, chartid=chartid) 
+  output <- gvisChart(type=my.type, checked.data=checked.data, options=my.options, 
+                      chartid=chartid, formats = formats) 
   
   return(output)
 }
